@@ -1,18 +1,15 @@
 use crate::Float;
+// use cached::{proc_macro::cached, SizedCache};
 
-pub fn create_parameters(parameter_range: (Float, Float), division: usize) -> Vec<Float> {
-    let (begin, end) = parameter_range;
-    let step = (end - begin) / division as Float;
-    let mut parameters = Vec::with_capacity(division + 1);
-    parameters.push(begin);
-    let mut u = begin;
-    for _ in 0..division - 1 {
-        u += step;
-        parameters.push(u);
-    }
-    parameters.push(end);
-    parameters
-}
+// fn make_key(n: usize, u: Float) -> u64 {
+//     u64::from_le_bytes(u.to_le_bytes()) | (n as u64)
+// }
+//
+// #[cached(
+//     type = "SizedCache<u64, Vec<Float>>",
+//     create = "{ SizedCache::with_size(1000) }",
+//     convert = r#"{ make_key(n, u) }"#
+// )]
 
 /// Compute values of (n-1)th-degree Bernstein polynomial
 pub fn bernstein(n: usize, u: Float) -> Vec<Float> {
@@ -32,3 +29,11 @@ pub fn bernstein(n: usize, u: Float) -> Vec<Float> {
 
     values
 }
+
+#[test]
+fn test_bernstein() {
+    assert_eq!(
+        bernstein(4, 0.25),
+        vec![0.421875, 0.421875, 0.140625, 0.015625,]
+    );
+}
